@@ -49,7 +49,7 @@ impl<E> Metadata<E> {
 }
 
 /// Base trait for all [WGSL host-shareable types](https://gpuweb.github.io/gpuweb/wgsl/#host-shareable-types)
-pub trait WgslType {
+pub trait ShaderType {
     #[doc(hidden)]
     type ExtraMetadata;
     #[doc(hidden)]
@@ -79,38 +79,107 @@ pub trait WgslType {
     }
 
     #[doc(hidden)]
-    const UNIFORM_COMPAT_ASSERT: () = ();
+    const UNIFORM_COMPAT_ASSERT: fn() = || {};
 
-    /// Asserts at compile time that `Self` meets the requirements of the
+    /// Asserts that `Self` meets the requirements of the
     /// [uniform address space restrictions on stored values](https://gpuweb.github.io/gpuweb/wgsl/#address-spaces-uniform) and the
     /// [uniform address space layout constraints](https://gpuweb.github.io/gpuweb/wgsl/#address-space-layout-constraints)
     ///
     /// # Examples
     ///
-    /// Will not compile since runtime-sized arrays are not compatible with the
+    /// ## Array
+    ///
+    /// Will panic since runtime-sized arrays are not compatible with the
     /// uniform address space restrictions on stored values
     ///
-    /// ```compile_fail,E0080
-    /// # use crate::encase::WgslType;
+    /// ```should_panic
+    /// # use crate::encase::ShaderType;
     /// <Vec<mint::Vector4<f32>>>::assert_uniform_compat();
     /// ```
     ///
-    /// Will not compile since the stride is 4 bytes
+    /// Will panic since the stride is 4 bytes
     ///
-    /// ```compile_fail,E0080
-    /// # use crate::encase::WgslType;
+    /// ```should_panic
+    /// # use crate::encase::ShaderType;
     /// <[f32; 2]>::assert_uniform_compat();
     /// ```
     ///
-    /// Will compile since the stride is 16 bytes
+    /// Will not panic since the stride is 16 bytes
     ///
     /// ```
-    /// # use crate::encase::WgslType;
+    /// # use crate::encase::ShaderType;
     /// # use mint;
     /// <[mint::Vector4<f32>; 2]>::assert_uniform_compat();
     /// ```
+    ///
+    /// ## Struct
+    ///
+    /// Will panic since runtime-sized arrays are not compatible with the
+    /// uniform address space restrictions on stored values
+    ///
+    /// ```should_panic
+    /// # use crate::encase::ShaderType;
+    /// # use mint;
+    /// #[derive(ShaderType)]
+    /// struct Invalid {
+    ///     #[size(runtime)]
+    ///     vec: Vec<mint::Vector4<f32>>
+    /// }
+    /// Invalid::assert_uniform_compat();
+    /// ```
+    ///
+    /// Will panic since the inner struct's size must be a multiple of 16
+    ///
+    /// ```should_panic
+    /// # use crate::encase::ShaderType;
+    /// #[derive(ShaderType)]
+    /// struct S {
+    ///     x: f32,
+    /// }
+    ///
+    /// #[derive(ShaderType)]
+    /// struct Invalid {
+    ///     a: f32,
+    ///     b: S, // offset between fields 'a' and 'b' must be at least 16 (currently: 4)
+    /// }
+    /// Invalid::assert_uniform_compat();
+    /// ```
+    ///
+    /// Will not panic (fixed via align attribute)
+    ///
+    /// ```
+    /// # use crate::encase::ShaderType;
+    /// # #[derive(ShaderType)]
+    /// # struct S {
+    /// #     x: f32,
+    /// # }
+    /// #[derive(ShaderType)]
+    /// struct Valid {
+    ///     a: f32,
+    ///     #[align(16)]
+    ///     b: S,
+    /// }
+    /// Valid::assert_uniform_compat();
+    /// ```
+    ///
+    /// Will not panic (fixed via size attribute)
+    ///
+    /// ```
+    /// # use crate::encase::ShaderType;
+    /// # #[derive(ShaderType)]
+    /// # struct S {
+    /// #     x: f32,
+    /// # }
+    /// #[derive(ShaderType)]
+    /// struct Valid {
+    ///     #[size(16)]
+    ///     a: f32,
+    ///     b: S,
+    /// }
+    /// Valid::assert_uniform_compat();
+    /// ```
     fn assert_uniform_compat() {
-        Self::UNIFORM_COMPAT_ASSERT
+        Self::UNIFORM_COMPAT_ASSERT()
     }
 
     // fn assert_can_write_into()
@@ -133,8 +202,8 @@ pub trait WgslType {
 }
 
 /// Trait implemented for all [WGSL fixed-footprint types](https://gpuweb.github.io/gpuweb/wgsl/#fixed-footprint-types)
-pub trait Size: WgslType {
-    /// Represents [WGSL Size](https://gpuweb.github.io/gpuweb/wgsl/#alignment-and-size) (equivalent to [`WgslType::min_size`])
+pub trait Size: ShaderType {
+    /// Represents [WGSL Size](https://gpuweb.github.io/gpuweb/wgsl/#alignment-and-size) (equivalent to [`ShaderType::min_size`])
     const SIZE: NonZeroU64 = Self::METADATA.min_size().0;
 }
 
