@@ -20,19 +20,10 @@
     html_logo_url = "https://raw.githubusercontent.com/teoxoy/encase/3d6d2e4d7670863e97463a15ceeafac6d13ee73e/logo.svg"
 )]
 
-/// Used to implement `WgslType` for structs
+/// Used to implement `ShaderType` for structs
 ///
 /// # Attributes
 ///
-/// Struct attributes
-///
-/// - `#[assert_uniform_compat]`
-/// used to assert at compile time that the struct meets the requirements of the
-/// [uniform address space restrictions on stored values](https://gpuweb.github.io/gpuweb/wgsl/#address-spaces-uniform) and the
-/// [uniform address space layout constraints](https://gpuweb.github.io/gpuweb/wgsl/#address-space-layout-constraints).
-///
-///     You can also use [`WgslType::assert_uniform_compat()`] instead
-///
 /// Field attributes
 ///
 /// - `#[align(X)]` where `X` is a power of 2 [`u32`] literal (equivalent to [WGSL align attribute](https://gpuweb.github.io/gpuweb/wgsl/#attribute-align))
@@ -51,8 +42,6 @@
 ///
 /// While structs using generic type parameters are supported by this derive macro
 ///
-/// - the `#[assert_uniform_compat]` attribute won't work with such a struct
-///
 /// - the `#[align(X)]` and `#[size(X)]` attributes will only work
 /// if they are attached to fields whose type contains no generic type parameters
 ///
@@ -62,8 +51,8 @@
 ///
 /// ```
 /// # use mint;
-/// # use crate::encase::WgslType;
-/// #[derive(WgslType)]
+/// # use crate::encase::ShaderType;
+/// #[derive(ShaderType)]
 /// struct AffineTransform2D {
 ///     matrix: mint::ColumnMatrix2<f32>,
 ///     translate: mint::Vector2<f32>
@@ -76,9 +65,9 @@
 ///
 /// ```
 /// # use mint;
-/// # use crate::encase::WgslType;
+/// # use crate::encase::ShaderType;
 /// # use crate::encase::ArrayLength;
-/// #[derive(WgslType)]
+/// #[derive(ShaderType)]
 /// struct Positions {
 ///     length: ArrayLength,
 ///     #[size(runtime)]
@@ -86,85 +75,16 @@
 /// }
 /// ```
 ///
-/// Assert uniform address space requirements
-///
-/// _Will not compile since runtime-sized arrays are not compatible with the
-/// uniform address space restrictions on stored values_
-///
-/// ```compile_fail,E0080
-/// # use crate::encase::WgslType;
-/// # use mint;
-/// #[derive(WgslType)]
-/// #[assert_uniform_compat]
-/// struct Invalid {
-///     #[size(runtime)]
-///     vec: Vec<mint::Vector4<f32>>
-/// }
-/// ```
-///
-/// _Will not compile since the inner struct's size must be a multiple of 16_
-///
-/// ```compile_fail,E0080
-/// # use crate::encase::WgslType;
-/// #[derive(WgslType)]
-/// struct S {
-///     x: f32,
-/// }
-///
-/// #[derive(WgslType)]
-/// #[assert_uniform_compat]
-/// struct Invalid {
-///     a: f32,
-///     b: S, // offset between fields 'a' and 'b' must be at least 16 (currently: 4)
-/// }
-/// ```
-///
-/// _Will compile (fixed via align attribute)_
-///
-/// ```
-/// # use crate::encase::WgslType;
-/// # #[derive(WgslType)]
-/// # struct S {
-/// #     x: f32,
-/// # }
-///
-/// #[derive(WgslType)]
-/// #[assert_uniform_compat]
-/// struct Valid {
-///     a: f32,
-///     #[align(16)]
-///     b: S,
-/// }
-/// ```
-///
-/// _Will compile (fixed via size attribute)_
-///
-/// ```
-/// # use crate::encase::WgslType;
-/// # #[derive(WgslType)]
-/// # struct S {
-/// #     x: f32,
-/// # }
-///
-/// #[derive(WgslType)]
-/// #[assert_uniform_compat]
-/// struct Valid {
-///     #[size(16)]
-///     a: f32,
-///     b: S,
-/// }
-/// ```
-///
 /// Complex
 ///
 /// ```
-/// # use crate::encase::WgslType;
-/// #[derive(WgslType)]
+/// # use crate::encase::ShaderType;
+/// #[derive(ShaderType)]
 /// struct Complex<
 ///     'a,
 ///     'b: 'a,
-///     E: 'a + WgslType + encase::Size,
-///     T: 'b + WgslType + encase::Size,
+///     E: 'a + ShaderType + encase::Size,
+///     T: 'b + ShaderType + encase::Size,
 ///     const N: usize,
 /// > {
 ///     array: [&'a mut E; N],
@@ -173,7 +93,7 @@
 /// }
 /// ```
 ///
-pub use encase_derive::WgslType;
+pub use encase_derive::ShaderType;
 
 #[macro_use]
 mod utils;
@@ -183,8 +103,8 @@ mod types;
 mod impls;
 
 pub use crate::core::{
-    CalculateSizeFor, DynamicStorageBuffer, DynamicUniformBuffer, Size, StorageBuffer,
-    UniformBuffer, WgslType,
+    CalculateSizeFor, DynamicStorageBuffer, DynamicUniformBuffer, ShaderType, Size, StorageBuffer,
+    UniformBuffer,
 };
 pub use types::runtime_sized_array::ArrayLength;
 
@@ -195,14 +115,14 @@ pub mod internal {
     };
 }
 
-/// Module containing items necessary to implement `WgslType` for runtime-sized arrays
+/// Module containing items necessary to implement `ShaderType` for runtime-sized arrays
 pub mod rts_array {
     #[doc(inline)]
     pub use super::impl_rts_array;
     pub use super::types::runtime_sized_array::{Length, Truncate};
 }
 
-/// Module containing items necessary to implement `WgslType` for vectors
+/// Module containing items necessary to implement `ShaderType` for vectors
 pub mod vector {
     #[doc(inline)]
     pub use super::impl_vector;
@@ -211,7 +131,7 @@ pub mod vector {
     };
 }
 
-/// Module containing items necessary to implement `WgslType` for matrices
+/// Module containing items necessary to implement `ShaderType` for matrices
 pub mod matrix {
     #[doc(inline)]
     pub use super::impl_matrix;
@@ -243,7 +163,7 @@ pub mod private {
     pub use super::utils::consume_zsts;
     pub use super::utils::ArrayExt;
     pub use super::CalculateSizeFor;
+    pub use super::ShaderType;
     pub use super::Size;
-    pub use super::WgslType;
     pub use const_panic::concat_assert;
 }
