@@ -4,12 +4,12 @@ pub trait MatrixScalar {}
 impl_marker_trait_for_f32!(MatrixScalar);
 
 pub struct MatrixMetadata {
-    pub row_padding: u64,
+    pub col_padding: u64,
 }
 
 impl Metadata<MatrixMetadata> {
-    pub const fn row_padding(self) -> u64 {
-        self.extra.row_padding
+    pub const fn col_padding(self) -> u64 {
+        self.extra.col_padding
     }
 }
 
@@ -28,7 +28,7 @@ pub trait FromMatrixParts<T: MatrixScalar, const C: usize, const R: usize> {
     fn from_parts(parts: [[T; R]; C]) -> Self;
 }
 
-/// Used to implement `WgslType` for the given matrix type
+/// Used to implement `ShaderType` for the given matrix type
 ///
 /// The given matrix type should implement any combination of
 /// [`AsRefMatrixParts`], [`AsMutMatrixParts`], [`FromMatrixParts`]
@@ -40,7 +40,7 @@ pub trait FromMatrixParts<T: MatrixScalar, const C: usize, const R: usize> {
 ///
 /// - `$r` nr of rows the given matrix contains
 ///
-/// - `$type` the type (representing a matrix) for which `WgslType` will be imeplemented for
+/// - `$type` the type (representing a matrix) for which `ShaderType` will be imeplemented for
 ///
 /// - `$generics` \[optional\] generics that will be passed into the `impl< >`
 ///
@@ -123,23 +123,23 @@ macro_rules! impl_matrix_inner {
             "Matrix should have at least 2 rows and at most 4!",
         );
 
-        impl<$($generics)*> $crate::private::WgslType for $type
+        impl<$($generics)*> $crate::private::ShaderType for $type
         where
             $el_ty: $crate::private::Size,
         {
             type ExtraMetadata = $crate::private::MatrixMetadata;
             const METADATA: $crate::private::Metadata<Self::ExtraMetadata> = {
-                let row_size = $crate::private::SizeValue::from(<$el_ty as $crate::private::Size>::SIZE).mul($r);
-                let alignment = $crate::private::AlignmentValue::from_next_power_of_two_size(row_size);
-                let size = alignment.round_up_size(row_size).mul($c);
-                let row_padding = alignment.padding_needed_for(row_size.get());
+                let col_size = $crate::private::SizeValue::from(<$el_ty as $crate::private::Size>::SIZE).mul($r);
+                let alignment = $crate::private::AlignmentValue::from_next_power_of_two_size(col_size);
+                let size = alignment.round_up_size(col_size).mul($c);
+                let col_padding = alignment.padding_needed_for(col_size.get());
 
                 $crate::private::Metadata {
                     alignment,
                     has_uniform_min_alignment: false,
                     min_size: size,
                     extra: $crate::private::MatrixMetadata {
-                        row_padding,
+                        col_padding,
                     },
                 }
             };
@@ -152,48 +152,48 @@ macro_rules! impl_matrix_inner {
 
         impl<$($generics)*> $crate::private::WriteInto for $type
         where
-            Self: $crate::private::AsRefMatrixParts<$el_ty, $c, $r> + $crate::private::WgslType<ExtraMetadata = $crate::private::MatrixMetadata>,
+            Self: $crate::private::AsRefMatrixParts<$el_ty, $c, $r> + $crate::private::ShaderType<ExtraMetadata = $crate::private::MatrixMetadata>,
             $el_ty: $crate::private::MatrixScalar + $crate::private::WriteInto,
         {
             fn write_into<B: $crate::private::BufferMut>(&self, writer: &mut $crate::private::Writer<B>) {
                 let columns = $crate::private::AsRefMatrixParts::<$el_ty, $c, $r>::as_ref_parts(self);
-                for row in columns {
-                    for el in row {
+                for col in columns {
+                    for el in col {
                         $crate::private::WriteInto::write_into(el, writer);
                     }
-                    writer.advance(<Self as $crate::private::WgslType>::METADATA.row_padding() as ::core::primitive::usize);
+                    writer.advance(<Self as $crate::private::ShaderType>::METADATA.col_padding() as ::core::primitive::usize);
                 }
             }
         }
 
         impl<$($generics)*> $crate::private::ReadFrom for $type
         where
-            Self: $crate::private::AsMutMatrixParts<$el_ty, $c, $r> + $crate::private::WgslType<ExtraMetadata = $crate::private::MatrixMetadata>,
+            Self: $crate::private::AsMutMatrixParts<$el_ty, $c, $r> + $crate::private::ShaderType<ExtraMetadata = $crate::private::MatrixMetadata>,
             $el_ty: $crate::private::MatrixScalar + $crate::private::ReadFrom,
         {
             fn read_from<B: $crate::private::BufferRef>(&mut self, reader: &mut $crate::private::Reader<B>) {
                 let columns = $crate::private::AsMutMatrixParts::<$el_ty, $c, $r>::as_mut_parts(self);
-                for row in columns {
-                    for el in row {
+                for col in columns {
+                    for el in col {
                         $crate::private::ReadFrom::read_from(el, reader);
                     }
-                    reader.advance(<Self as $crate::private::WgslType>::METADATA.row_padding() as ::core::primitive::usize);
+                    reader.advance(<Self as $crate::private::ShaderType>::METADATA.col_padding() as ::core::primitive::usize);
                 }
             }
         }
 
         impl<$($generics)*> $crate::private::CreateFrom for $type
         where
-            Self: $crate::private::FromMatrixParts<$el_ty, $c, $r> + $crate::private::WgslType<ExtraMetadata = $crate::private::MatrixMetadata>,
+            Self: $crate::private::FromMatrixParts<$el_ty, $c, $r> + $crate::private::ShaderType<ExtraMetadata = $crate::private::MatrixMetadata>,
             $el_ty: $crate::private::MatrixScalar + $crate::private::CreateFrom,
         {
             fn create_from<B: $crate::private::BufferRef>(reader: &mut $crate::private::Reader<B>) -> Self {
                 let columns = $crate::private::ArrayExt::from_fn(|_| {
-                    let row = $crate::private::ArrayExt::from_fn(|_| {
+                    let col = $crate::private::ArrayExt::from_fn(|_| {
                         $crate::private::CreateFrom::create_from(reader)
                     });
-                    reader.advance(<Self as $crate::private::WgslType>::METADATA.row_padding() as ::core::primitive::usize);
-                    row
+                    reader.advance(<Self as $crate::private::ShaderType>::METADATA.col_padding() as ::core::primitive::usize);
+                    col
                 });
 
                 $crate::private::FromMatrixParts::<$el_ty, $c, $r>::from_parts(columns)
