@@ -1,8 +1,8 @@
-use encase::WgslType;
+use encase::ShaderType;
 
 fn main() {}
 
-#[derive(WgslType)]
+#[derive(ShaderType)]
 struct Test {
     #[align]
     a: u32,
